@@ -63,7 +63,7 @@ class DB:
         self._conn = self._connect()
 
     def _call_fn(self, query, fn, *args, **kwargs):
-        """Forward method call to anosql query
+        """Forward method call to aiosql query
 
         On connection failure, it will try to reconnect on the next call
         if auto_reconnect was specified.
@@ -73,7 +73,7 @@ class DB:
         the next call should be on a different request.
         """
         if self._debug:
-            log.debug(f"DB y: {query}({args}, {kwargs})")
+            log.debug(f"DB: {query}({args}, {kwargs})")
         if self._reconn and self._auto_reconnect:
             self._reconnect()
         try:
@@ -91,16 +91,18 @@ class DB:
             if hasattr(self._conn, 'closed') and self._conn.closed == 2 and \
                self._auto_reconnect:
                 self._reconn = True
+            # re-raise error
             raise error
 
+    # this could probably be done dynamic by overriding __getattribute__
     def _create_fns(self, queries: sql.aiosql.Queries):
         """Create call forwarding to insert the database connection."""
         self._queries.append(queries)
         for q in queries.available_queries:
             f = getattr(queries, q)
+            # we skip internal *_cursor attributes
             if callable(f):
-                setattr(self, q,
-                        ft.partial(self._call_fn, q, getattr(queries, q)))
+                setattr(self, q, ft.partial(self._call_fn, q, f))
                 self._available_queries.add(q)
                 self._count[q] = 0
 
@@ -122,7 +124,7 @@ class DB:
             import psycopg2 as db  # type: ignore
             return db.connect(self._conn_str, **self._conn_options)
         else:
-            # note: anosql currently supports sqlite & postgres
+            # note: aiosql currently supports sqlite & postgres
             raise Exception(f"unexpected db {self._db}")
 
     def _reconnect(self):
@@ -144,6 +146,8 @@ class DB:
 
     def cursor(self):
         """Get a cursor on the current connection."""
+        if self._reconn and self._auto_reconnect:
+            self._reconnect()
         return self._conn.cursor()
 
     def commit(self):
